==> benno-web-2.2.0.tgz: srv/benno/bennoweb/htdocs/ctrl/downloadAttachment.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

// EMail from session (s.a. pre_ctrl)
$filename    = $App->getParam('name');
$contentType = $App->getParam('type');
$sessionMailId = $App->getParam('id');

try {
    $attachmentData = $Backend->fetchAttachment($sessionMailId,$filename);

    header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
    header("Pragma: public");
    header('Content-Type: '.$contentType);
    header("Content-Disposition: attachment; filename=\"$filename\";");

    print $attachmentData;
    exit;
}
catch (Exception $e) {
    $App->log('[downloadAttachment] '.$e->getMessage());
    $App->setMsg($e->getMessage());
    $App->view = 'error';
}

?>

==> benno-web-2.2.1.tgz: srv/benno/bennoweb/htdocs/ctrl/downloadAttachment.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

// EMail from session (s.a. pre_ctrl)
$filename    = $App->getParam('name');
$contentType = $App->getParam('type');
$sessionMailId = $App->getParam('id');

try {
    $attachmentData = $Backend->fetchAttachment($archive,$sessionMailId,$filename);

    header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
    header("Pragma: public");
    header('Content-Type: '.$contentType);
    header("Content-Disposition: attachment; filename=\"$filename\";");

    print $attachmentData;
    exit;
}
catch (Exception $e) {
    $App->log('[downloadAttachment] '.$e->getMessage());
    $App->setMsg($e->getMessage());
    $App->view = 'error';
}

?>
